@@ -1,27 +1,26 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import json
+import urllib.request
 import datetime
-import os
-import sys
+import validators
 
-from bson.objectid import ObjectId
 import pathos
 import pathos.pools as pp
 import psutil
 import ray
+from bson.objectid import ObjectId
 from tqdm import tqdm
 
+import deepnlpf.log as log
 from deepnlpf.core.output_format import OutputFormat
 from deepnlpf.core.plugin_manager import PluginManager
 from deepnlpf.core.util import Util
 from deepnlpf.global_parameters import *
-import deepnlpf.log as log
-from deepnlpf.util.random_object_id import RandomObjectId
-
 from deepnlpf.notifications.toast import Toast
-
 from deepnlpf.templates.schema import *
+from deepnlpf.util.random_object_id import RandomObjectId
 
 
 class Pipeline(object):
@@ -47,12 +46,13 @@ class Pipeline(object):
         memory: int = None,
         num_cpus: int = 0,
         num_gpus: float = 0,
+        use_cluster: bool = False
     ):
 
         self.toast = Toast()
 
         log.logger.info("--------------------- Start ---------------------")
-        self.toast.show("success", "DeepNLPF", "Start processing!")
+        #self.toast.show("success", "DeepNLPF", "Start processing!")
 
         self._input = _input
         self._input_type = self.check_input_type_dataset(_input)
@@ -78,15 +78,18 @@ class Pipeline(object):
         self._id_pool = ObjectId(b"foo-bar-quux")
         log.logger.info("Pool: {}".format(self._id_pool))
 
-        self._boost = boost
-        log.logger.info("Boost: {}".format(boost))
+        if use_cluster == False:
+            self._boost = boost
+            log.logger.info("Boost: {}".format(boost))
+            
+            self._memory = memory
 
-        self._memory = memory
+            self.init_cpus(num_cpus)
+            self.init_local()
 
-        self.init_cpus(num_cpus)
-        self.init_boost()
-
-        self.GPUS_COUNT = num_gpus
+            self.GPUS_COUNT = num_gpus
+        else:
+            self.init_cluster()
 
     def init_cpus(self, cpus):
         """Initializes the CPUs
@@ -101,15 +104,23 @@ class Pipeline(object):
         else:
             self.CPUS_COUNT = cpus  # define quant cpus info user.
 
-    def init_boost(self):
-        """Starts the selected boost with the default or specified settings.
-        """
+    def init_local(self):
+        """Starts the selected boost with the default or specified settings."""
         if self._boost == "pathos":
             self._id_pool = pp.ProcessPool(self.CPUS_COUNT)
         elif self._boost == "ray":
-            ray.init(
-                memory=self._memory, num_cpus=self.CPUS_COUNT, num_gpus=self.GPUS_COUNT
+            if(self._memory!=None):
+                ray.init(
+                    memory=self._memory, num_cpus=self.CPUS_COUNT, num_gpus=self.GPUS_COUNT
+                )
+            else:
+                ray.init(
+                    num_cpus=self.CPUS_COUNT, num_gpus=self.GPUS_COUNT
             )
+                
+
+    def init_cluster(self):
+        ray.init(address='auto')
 
     def check_input_type_dataset(self, _input: str) -> str:
         """Checks how the dataset is entered. [path_dataset|id_dataset|raw_text].
@@ -138,8 +149,8 @@ class Pipeline(object):
 
             log.logger.info("Input data type: {}".format(result))
             return result
-        except Exception as error:
-            print(error)
+        except Exception as err:
+            log.logger.error(err)
             sys.exit(0)
 
     def check_input_format_pipeline(self, pipeline: str) -> str:
@@ -155,11 +166,18 @@ class Pipeline(object):
         result = ""
 
         try:
-            if os.path.isfile(pipeline):  # check is file.
+            # check is file.
+            if os.path.isfile(pipeline):
                 file_name, ext = pipeline.split(".")
                 result = (
                     ext.lower()
                 )  # if the file extension was in capital letters it reduces to lower case.
+            # check is url.
+            elif validators.url(pipeline):
+                result = "url"
+            # check is json str
+            elif json.loads(pipeline):
+                result = "json_str"
             else:
                 print(
                     "Enter a parameter from a valid pipeline {}.".format(
@@ -171,8 +189,8 @@ class Pipeline(object):
             log.logger.info("Input pipeline type format: {}".format(result))
 
             return result
-        except Exception as error:
-            print(error)
+        except Exception as err:
+            log.logger.error(err)
             sys.exit(0)
 
     def load_file_pipeline(self, pipeline: str, pipeline_type: str):
@@ -194,11 +212,16 @@ class Pipeline(object):
                 result = OutputFormat().yaml2json(pipeline)
             elif pipeline_type == "xml":
                 result = OutputFormat().xml2json(pipeline)
+            elif pipeline_type == "url":
+                with urllib.request.urlopen(pipeline) as url:
+                    result = json.loads(url.read().decode())
+            elif pipeline_type == "json_str":
+                result = json.loads(pipeline)
 
             log.logger.info("Custom Pipeline: {}".format(result))
             return result
-        except Exception as error:
-            print(error)
+        except Exception as err:
+            log.logger.error(err)
             sys.exit(0)
 
     def load_dataset(self, _input_type):
@@ -234,7 +257,6 @@ class Pipeline(object):
             return documents
 
     def annotate(self):
-
         self.DOCUMENTS = self.load_dataset(self._input_type)
 
         log.logger.info(
@@ -270,7 +292,7 @@ class Pipeline(object):
             self.RESULT = ray.get(futures)
 
         log.logger.info("--------------------- End ---------------------")
-        self.toast.show("success", "DeepNLPF", "End processing.")
+        #self.toast.show("success", "DeepNLPF", "End processing.")
 
         if self._output == "file":
             return {
@@ -303,6 +325,7 @@ class Pipeline(object):
                         "_id_dataset": self.ID_DATASET,
                         "_id_document": document["_id"],
                         "_id_pool": self._id_pool,
+                        "tool": tool,
                         "sentences": annotated_document,
                     },
                 )
@@ -402,6 +425,7 @@ class Pipeline(object):
 
         # pre-processing tokenization and ssplit using plugin base selected.
         if self._tool_base == "stanza":
+            
             doc_annotation = PluginManager().call_plugin_nlp(
                 plugin_name="preprocessing",
                 document=raw_text,
